@@ -4,16 +4,37 @@ use strict;
 use warnings;
 
 # ABSTRACT: configure Dist::Zilla like RUSSOZ
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
 
 use Dist::Zilla 4.102341;    # dzil authordeps
 use Dist::Zilla::PluginBundle::TestingMania 0.012;
+use Dist::Zilla::Plugin::MetaJSON;
+use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::InstallGuide;
+use Dist::Zilla::Plugin::Signature;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+has auto_prereqs => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => 1,
+);
+
+has signature => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub {
+        ( defined $_[0]->payload->{signature}
+              and $_[0]->payload->{signature} == 1 ) ? 1 : 0;
+    },
+);
+
 has twitter => (
     is      => 'ro',
     isa     => 'Bool',
@@ -24,13 +45,6 @@ has twitter => (
     },
 );
 
-has auto_prereqs => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 1,
-);
-
 has twitter_tags => (
     is      => 'ro',
     isa     => 'Str',
@@ -85,6 +99,8 @@ sub configure {
         ]
     ) if ( $self->twitter );
 
+    $self->add_plugins('Signature') if $self->signature;
+
     return;
 }
 
@@ -105,7 +121,7 @@ Dist::Zilla::PluginBundle::Author::RUSSOZ - configure Dist::Zilla like RUSSOZ
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
